@@ -44,12 +44,7 @@ def __init__ (value,parseMemory):
         parseMemory[5]=parseMemory[5].replace('|DATA0|',value+'|DATA0|')
     # if this is var & is named
     elif '|DATA1|' in parseMemory[5]:
-        if parseMemory[6]:
-            parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
-        else:
-            #print(parseMemory)
-            raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nVariable opened without assign')
-        # line is empty
+        parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
     elif parseMemory[5]=='':
         parseMemory[5]+=f'{value}|DATA|'
     else:
