@@ -16,9 +16,6 @@ def __init__ (value,parseMemory):
         if value=='':
             raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nNumber Can\'t be zero')
 
-    if ('|DATA0|' in parseMemory[5]):
-        #print(parseMemory[5])
-        raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nVariable not named yet')
     # if |DATA-P| not set yet    
     if '|DATA-P|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA-P|',value)
@@ -26,12 +23,10 @@ def __init__ (value,parseMemory):
     elif '|DATA|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA|',f'{value}|DATA|')
     # var item bar found
+    elif '|DATA0|' in parseMemory[5]:
+        parseMemory[5]=parseMemory[5].replace('|DATA0|',f'{value}|DATA0|')
     elif '|DATA1|' in parseMemory[5]:
-        if parseMemory[6]:
-            parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
-        else:
-            raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nVariable opened without assign')
-                
+        parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
     elif parseMemory[5]=='':
         parseMemory[5]+=f'{value}|DATA|'
     else:
