@@ -6,14 +6,14 @@ def __init__ (value, parseMemory):
     if 'try :' in parseMemory[5]:
         raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nCan\'t add any arguments to try command')
     
-    
+    if '|DATA_N|' in parseMemory[5]:
+        raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nComplete function sentence')
     if '|DATA-P|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA-P|','')
     if '|DATA|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA|',f'{value}|DATA|')
-    elif ('|DATA1|' in parseMemory[5]) and (parseMemory[6] == False):
-        #print(parseMemory)
-        raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nVariable opened without assign')
+    elif '|DATA0|' in parseMemory[5]:
+        parseMemory[5]=parseMemory[5].replace('|DATA0|',f'{value}|DATA0|')
     elif '|DATA1|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
     else:
